﻿using RoomiezApp.Database;
using RoomiezApp.Forms.MainWindowPanels;
using RoomiezApp.Model;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RoomiezApp.Forms
{
    public partial class MainWindow : Form
    {
        private Roommate _user;
        private Flat _flat;
        private DBContext _db;

        public MainWindow(Roommate user, Flat flat, DBContext db)
        {
            _user = user;
            _flat = flat;
            _db = db;
            InitializeComponent();
        }

        private void MainWindow_Load(object sender, EventArgs e)
        {
            dateLabel.Text = DateTime.Now.ToString("ddd, d MMMM yyyy");
            userNameLabel.Text = _user.Name;
            flatNameLabel.Text = _flat.Name;
            this.Text += _flat.Name;

            summaryButton_Click(this, EventArgs.Empty);
        }

        private void buttonSetActive(Button button)
        {
            button.Font = new Font(button.Font.Name, button.Font.Size, FontStyle.Bold);
            button.ForeColor = Color.FromArgb(79, 109, 204);
        }

        private void buttonSetInactive(Button button)
        {
            button.Font = new Font(button.Font.Name, button.Font.Size, FontStyle.Regular);
            button.ForeColor = Color.FromArgb(176, 174, 174);
        }

        private void resetBeforePanelChange()
        {
            buttonSetInactive(summaryButton);
            buttonSetInactive(taskButton);
            buttonSetInactive(calendarButton);
            buttonSetInactive(financeButton);
            contentsPanel.Controls.Clear();
        }

        private void taskButton_Click(object sender, EventArgs e)
        {
            resetBeforePanelChange();
            buttonSetActive(taskButton);
            Tasks tF = new Tasks(_flat) { Dock = DockStyle.Fill, TopLevel = false };
            contentsPanel.Controls.Add(tF);
            tF.Show();
        }

        private void summaryButton_Click(object sender, EventArgs e)
        {
            resetBeforePanelChange();
            buttonSetActive(summaryButton);
            Summary sF = new Summary(_flat, _user, _db) { Dock = DockStyle.Fill, TopLevel = false };
            sF.NameChanged += changeFlatName_NameChanged;
            contentsPanel.Controls.Add(sF);
            sF.Show();
        }

        private void financeButton_Click(object sender, EventArgs e)
        {
            resetBeforePanelChange();
            buttonSetActive(financeButton);
            Finances fF = new Finances(_flat) { Dock = DockStyle.Fill, TopLevel = false }; ;
            contentsPanel.Controls.Add(fF);
            fF.Show();
        }

        private void calendarButton_Click(object sender, EventArgs e)
        {
            resetBeforePanelChange();
            buttonSetActive(calendarButton);
            Calendar cF = new Calendar(_flat, _user) { TopLevel = false }; ;
            contentsPanel.Controls.Add(cF);
            cF.Show();
        }

        private void changeFlatName_NameChanged(object sender, string newName)
        {
            if (sender == null)
            {
                return;
            }

            flatNameLabel.Text = newName;
            this.Text = "Roomiez | " + newName;
        }
    }
}
